@@ -5,13 +5,15 @@ import text2text as t2t
 class Searcher(t2t.Transformer):
   
   def transform(self, input_lines, queries, src_lang='en', vector_class=t2t.Tfidfer, index=None, **kwargs):
-    t2t.Transformer.transform(self, input_lines, src_lang, **kwargs)
+    input_lines = t2t.Transformer.transform(self, input_lines, src_lang, **kwargs)
     search_object = vector_class()
 
     if index is None:
       index = search_object.transform(input_lines, src_lang='en', output="matrix")
-    if type(queries) != list:
+    if type(queries) == str:
       queries = [queries]
+    elif type(queries) != list:
+      queries = list(queries)
     queries = search_object.transform(queries, src_lang='en', output="matrix", use_idf=False)
     
     if type(queries) is np.ndarray and type(index) is np.ndarray:
@@ -26,5 +28,5 @@ class Searcher(t2t.Transformer):
         queries = sp.hstack([queries,padding], format="csr")
       scores = queries.dot(index.transpose())
     else:
-      TypeError("Invalid type for queries and/or index.")
+      raise TypeError("Invalid type for queries and/or index.")
     return scores
\ No newline at end of file
