@@ -2,7 +2,7 @@ import text2text as t2t
 
 class Variator(t2t.Translator):
   def transform(self, input_lines, src_lang='en', **kwargs):
-    t2t.Transformer.transform(self, input_lines, src_lang=src_lang, **kwargs)
+    input_lines = t2t.Transformer.transform(self, input_lines, src_lang=src_lang, **kwargs)
     output_lines = []
     src_lang = src_lang
     for tgt_lang in self.__class__.LANGUAGES:
